@@ -14,7 +14,8 @@
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
+  MA 02110-1301, USA.
 
 */
 
@@ -277,8 +278,8 @@ private:
 
 	//! Retrieve the data (name/URL) for a single entry (TOC or index)
 	bool GetItem(UCharPtr& topics, UCharPtr& strings, UCharPtr& urltbl,
-		     UCharPtr& urlstr, u_int32_t index, wxTreeCtrl *toBuild,
-		     CHMListCtrl* toBuild, const wxString& idxName,
+		     UCharPtr& urlstr, u_int32_t index, wxTreeCtrl* tree,
+		     CHMListCtrl* list, const wxString& idxName,
 		     const wxCSConv& cv, int level, bool local);
 
 	//! Get the binary index (if available)
