@@ -18,7 +18,8 @@
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
+  MA 02110-1301, USA.
 
 */
 
@@ -80,13 +81,13 @@ const wxChar *greeting = wxT(
 	" Pabs' <TT>GPL</TT>d <TT>chmdeco</TT> code.<br><br>If"
 	" you'd like to use the code in your own stuff please figure"
 	" <TT>GPL</TT> out first. Far too many people think the <TT>GPL</TT> "
-	"is bad out of utter ignorance."
+	"is bad out of utter ignorance.")
 #if !defined(wxUSE_UNICODE) || !wxUSE_UNICODE
-	"<br><br><B>WARNING</B>: your <B>xCHM</B> binary is linked against a "
+	wxT("<br><br><B>WARNING</B>: your <B>xCHM</B> binary is linked against a "
 	"non-Unicode version of wxWidgets! While it will work with most "
-	"CHMs, it might not properly display special character languages."
+	"CHMs, it might not properly display special character languages.")
 #endif
-	"<br><br>Tips:<br><ul><li>"
+	wxT("<br><br>Tips:<br><ul><li>"
 	"The global search is an \'AND\' search, i.e. searching for"
 	" \'word1 word2\' (quotes not included) will find all the pages"
 	" that contain both word1 and word2, in whatever order.</li>"
@@ -145,6 +146,7 @@ CHMFrame::CHMFrame(const wxString& title, const wxString& booksDir,
 	wxApp::s_macAboutMenuItemId = ID_About;
 #endif
 
+	wxLogNull wln;
 	int sizes[7];
 	for(int i = -3; i <= 3; ++i)
 		sizes[i+3] = _fontSize + i * 2;
@@ -244,6 +246,8 @@ void CHMFrame::OnOpen(wxCommandEvent& WXUNUSED(event))
 
 void CHMFrame::OnChangeFonts(wxCommandEvent& WXUNUSED(event))
 {
+	wxLogNull wln;
+
 	// First time initialization only.
 	if(_normalFonts == NULL) {
 		wxFontEnumerator enu;
@@ -387,6 +391,8 @@ void CHMFrame::OnRegisterExtension(wxCommandEvent& WXUNUSED(event))
 
 void CHMFrame::OnPrint(wxCommandEvent& WXUNUSED(event))
 {
+	wxLogNull wln;
+
         int sizes[7];
 	        for(int i = -3; i <= 3; ++i)
 	                sizes[i+3] = _fontSize + i * 2;
@@ -1016,6 +1022,7 @@ BEGIN_EVENT_TABLE(CHMFrame, wxFrame)
 	EVT_BUTTON(ID_Remove, CHMFrame::OnRemoveBookmark)
 	EVT_TREE_SEL_CHANGED(ID_TreeCtrl, CHMFrame::OnSelectionChanged)
 	EVT_COMBOBOX(ID_Bookmarks, CHMFrame::OnBookmarkSel)
+	EVT_TEXT_ENTER(ID_Bookmarks, CHMFrame::OnBookmarkSel)
 	EVT_CLOSE(CHMFrame::OnCloseWindow)
 	EVT_CHAR(CHMFrame::OnChar)
 END_EVENT_TABLE()
