@@ -14,7 +14,8 @@
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
+  MA 02110-1301, USA.
 
 */
 
@@ -23,7 +24,6 @@
 #include <chminputstream.h>
 
 
-
 // only needs to be here because I killed the constructors
 // by providing a private copy constructor
 CHMFSHandler::CHMFSHandler()
@@ -77,7 +77,8 @@ wxFSFile* CHMFSHandler::OpenFile(wxFileSystem& fs,
 		right = right.Mid(len);
 
         wxFileName fwfn(right, wxPATH_UNIX);
-        fwfn.Normalize(wxPATH_NORM_DOTS | wxPATH_NORM_ABSOLUTE, cwd);
+        fwfn.Normalize(wxPATH_NORM_DOTS | wxPATH_NORM_ABSOLUTE, cwd, 
+			wxPATH_UNIX);
 	right = fwfn.GetFullPath(wxPATH_UNIX);
 
 	s = new CHMInputStream(left.IsEmpty() ? 
